pub struct IntegrityMsg {
pub total_bytes: u64,
pub completed_bytes: u64,
pub total_chunks: u32,
pub completed_chunks: u32,
pub chunk_size: u32,
}Expand description
Message data for integrity checking-related messages
Fields
total_bytes: u64The number of bytes in the WIM file that are covered by integrity checks
completed_bytes: u64The number of bytes that have been checksummed so far
total_chunks: u32The number of individually checksummed »chunks« the integrity-checked region is divided into
completed_chunks: u32The number of chunks that have been checksummed so far
chunk_size: u32The size of each individually checksummed “chunk” in the integrity-checked region